pub const fn kv_bytes_per_token(
elems: KvElemsPerToken,
k: KvCacheType,
v: KvCacheType,
) -> u64Expand description
Convert per-token K/V element counts to bytes at the given cache types.
pub const fn kv_bytes_per_token(
elems: KvElemsPerToken,
k: KvCacheType,
v: KvCacheType,
) -> u64Convert per-token K/V element counts to bytes at the given cache types.